@@ -89,6 +89,10 @@ gupnp_context_manager_new              (GMainContext *main_context,
 GUPnPContextManager *
 gupnp_context_manager_create           (guint port);
 
+void
+gupnp_context_manager_rescan_control_points
+                                       (GUPnPContextManager *manager);
+
 void
 gupnp_context_manager_manage_control_point
                                        (GUPnPContextManager     *manager,
